**This is a really, really bad API document.** I'm working to make Sphinx generate a better one
but, right now, the description on the homepage about how to use SKiDL is much better than this. 

SKiDL API
======================================

.. toctree::
   :maxdepth: 4

   overview
   modules


Indices and tables
==================

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`

